# Introduction #
Deep Learning Runtime (DLR) is a library that can run models optimized by Deep Learning Compiler (DLC), configured on SageMaker. For more information, please refer to DLR/DLC documentation.

This package includes:
* DLR Python packages for python 2.7.
* Example model of Resnet-50 compiled by DLC.
* Greengrass inference example.
* Greengrass Core Python SDK 1.2.0.
* LICENSE

# Install DLR On Your Device #

The DLR 1.0.0 on Jetson TX2 requires:
* CUDA 9.0
* cuDNN 7.1.5
* TensorRT 4.0

You can use Jetpack 3.3 to set up your device with these dependencies.

Install DLR on your system
```
sudo chmod 755 install-dlr.sh
sudo ./install-dlr.sh
```

Note: installation script will also install below requirements on your system if you don't have them installed before:
* pip
* numpy
* setuptools

# Example of using DLR in Greengrass #
1. Make sure you installed DLR in python 2.7 by running commands below.
   ```
   python --version
   python -c "import dlr"
   ```

2. Make sure that the DLR is installed and the "ggc_user" can use it by running commands below.
   ```
   sudo -u ggc_user bash -c 'python -c "import dlr"'
   ```

3. Follow the instructions at: https://docs.aws.amazon.com/greengrass/latest/developerguide/ml-dlc-console.html to setup your device with AWS Greengrass example.

4. Enable your onboard camera with ML inference.

   In order to take a photo with onboard camera on the Jetson, your python OpenCV has to be
   built with GStreamer enabled. We've tested OpenCV 3.4.0 on Jetson TX2 with Jetpack 3.3.

   Before using your camera to perform ML inference, please run command to check your OpenCV:
   ```
   python -c "import cv2; print(cv2.getBuildInformation());" | grep -A 5 "GStreamer"
   ```

   If your OpenCV has been built with GStreamer, you should see:
   ```
       GStreamer:
         base:                      YES (ver 1.8.3)
         video:                     YES (ver 1.8.3)
         app:                       YES (ver 1.8.3)
         riff:                      YES (ver 1.8.3)
         pbutils:                   YES (ver 1.8.3)
    ```

# License #
Please see the included document for license information.
