#
# Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# This class is a camera that uses OpenCV with GStreamer to take a photo and uses
# DLC compiled Resnet-50 model to perform image classification, identifying the
# object shown in the photo.
#
import cv2

class Camera(object):
    r"""
    Camera that captures an image for performing inference
    with DLC compiled model.
    """
    def capture_image(self, width, height):
        r"""
        Capture image with OpenCV.
        """
        try:
            gst_str = ('nvcamerasrc ! '
                       'video/x-raw(memory:NVMM), '
                       'width=(int)2592, height=(int)1458, '
                       'format=(string)I420, framerate=(fraction)30/1 ! '
                       'nvvidconv ! '
                       'video/x-raw, width=(int){}, height=(int){}, '
                       'format=(string)BGRx ! '
                       'videoconvert ! appsink').format(width, height)
            camera = cv2.VideoCapture(gst_str, cv2.CAP_GSTREAMER)

            # cv_image is a numpy array that represents the photo captured.
            # retval indicates whether the call was successful.
            retval, cv_image = camera.read()

            if(retval):
                return cv_image

        finally:
            cv2.destroyAllWindows()

        raise RuntimeError("There is problem for using your camera.")

# Test your camera and OpenCV.
if __name__ == "__main__":
    my_camera = Camera()
    my_camera.capture_image(800, 600)
    print("Your camera was initialized successfully.")
